@@ -6,10 +6,12 @@
 *    are observations that seem too distant from the others in a 1-D distribution for the column that the split tries
 *    to "predict" (will not generate a score for each observation).
 *    Splits are based on gain, while outlierness is based on confidence intervals.
-*    Similar in spirit to the GritBot software developed by RuleQuest research.
+*    Similar in spirit to the GritBot software developed by RuleQuest research. Reference article is:
+*      Cortes, David. "Explainable outlier detection through decision tree conditioning."
+*      arXiv preprint arXiv:2001.00636 (2020).
 *    
 *    
-*    Copyright 2019 David Cortes.
+*    Copyright 2020 David Cortes.
 *    
 *    Written for C++11 standard and OpenMP 2.0 or later. Code is meant to be wrapped into scripting languages
 *    such as R or Python.
@@ -122,53 +124,66 @@ void calculate_lowerlim_proportion(long double *restrict prop_small, long double
     }
 }
 
+
 /* Check if a numerical column has no variance (i.e. will not be splittable) */
 void check_missing_no_variance(double numeric_data[], size_t ncols, size_t nrows, bool has_NA[], bool skip_col[], int nthreads)
 {
-    long double sum;
-    long double sum_sq;
+    long double running_mean;
+    long double mean_prev;
+    long double running_ssq;
     size_t cnt;
     size_t col_stop;
+    double xval;
 
-    #pragma omp parallel for schedule(static) num_threads(nthreads) private(sum, sum_sq, cnt, col_stop)
+    #pragma omp parallel for schedule(static) num_threads(nthreads) private(running_mean, mean_prev, running_ssq, cnt, col_stop, xval)
     for (size_t col = 0; col < ncols; col++) {
-        sum = 0;
-        sum_sq = 0;
+        running_mean = 0;
+        mean_prev = 0;
+        running_ssq = 0;
         cnt = 0;
         col_stop = (col + 1) * nrows;
         for (size_t row = col * nrows; row < col_stop; row++) {
-            if (!is_na_or_inf(numeric_data[row])) {
-                sum    += numeric_data[row];
-                sum_sq += square(numeric_data[row]);
-                cnt++;
+            xval = numeric_data[row];
+            if (!is_na_or_inf(xval)) {
+                running_mean += (xval - running_mean) / (long double)(++cnt);
+                running_ssq  += (xval - running_mean) * (xval - mean_prev);
+                mean_prev     = running_mean;
             } else {
                 has_NA[col] = true;
             }
         }
-        if (fabs(sum_sq - square(sum) / (long double)cnt) < 1e-1) skip_col[col] = true;
+        if (  (running_ssq / (long double)(cnt - 1))  < 1e-6 ) skip_col[col] = true;
     }
 }
 
 /* Calculate mean and standard deviation from the central half of the data, and adjust SD heuristically by x2.5 */
 void calc_central_mean_and_sd(size_t ix_arr[], size_t st, size_t end, double x[], size_t size_quarter, double *mean_central, double *sd_central)
 {
-    long double sum = 0;
-    long double sum_sq = 0;
+    long double running_mean = 0;
+    long double mean_prev    = 0;
+    long double running_ssq  = 0;
+    double xval;
+    size_t st_offset = st + size_quarter;
     if (ix_arr != NULL) {
-        for (size_t row = (st + size_quarter); row <= (end - size_quarter); row++) {
-            sum    += x[ix_arr[row]];
-            sum_sq += square(x[ix_arr[row]]);
+        for (size_t row = st_offset; row <= (end - size_quarter); row++) {
+            xval = x[ix_arr[row]];
+            running_mean += (xval - running_mean) / (long double)(row - st_offset + 1);
+            running_ssq  += (xval - running_mean) * (xval - mean_prev);
+            mean_prev     = running_mean;
         }
     } else {
-        for (size_t row = (st + size_quarter); row <= (end - size_quarter); row++) {
-            sum    += x[row];
-            sum_sq += square(x[row]);
+        for (size_t row = st_offset; row <= (end - size_quarter); row++) {
+            xval = x[row];
+            running_mean += (xval - running_mean) / (long double)(row - st_offset + 1);
+            running_ssq  += (xval - running_mean) * (xval - mean_prev);
+            mean_prev     = running_mean;
         }
     }
-    *mean_central = sum / (long double)(2 * size_quarter);
-    *sd_central = 2.5 * calc_sd(2 * size_quarter, sum, sum_sq);
+    *mean_central = (double) running_mean;
+    *sd_central   = 2.5 * sqrtl(running_ssq / (long double)(end - st - 2 * size_quarter));
 }
 
+
 /*    Check whether a numerical column has long tails, and whether a transformation is appropriate
 *    
 *    Will check if there are too many observations with large Z values at either side. If found, will
@@ -434,6 +449,7 @@ void allocate_thread_workspace(Workspace &workspace, size_t nrows, int max_categ
     workspace.outlier_clusters.resize(nrows);
     workspace.outlier_trees.resize(nrows);
     workspace.outlier_depth.resize(nrows);
+    workspace.buffer_sd.resize(nrows);
 
     workspace.buffer_cat_sum.resize(max_categ + 1);
     workspace.buffer_cat_sum_sq.resize(max_categ + 1);
@@ -581,7 +597,7 @@ void check_more_two_values(double arr_num[], size_t nrows, size_t ncols, int nth
     std::vector<std::unordered_set<double>> seen_values(ncols);
 
     #pragma omp parallel for schedule(dynamic) num_threads(nthreads) shared(arr_num, nrows, ncols, too_few_values, seen_values)
-    for (size_t col = 0; col < ncols; col++) {
+    for (size_t_for col = 0; col < ncols; col++) {
         for (size_t row = 0; row < nrows; row++) {
             if (!isnan(arr_num[row + col * nrows]))
                 seen_values[col].insert(arr_num[row + col * nrows]);
@@ -590,3 +606,14 @@ void check_more_two_values(double arr_num[], size_t nrows, size_t ncols, int nth
         if (seen_values[col].size() <= 2)too_few_values[col] = true;
     }
 }
+
+/* Reason behind this function: Cython (as of v0.29) will not auto-deallocate
+   structs which are part of a cdef'd class, which produces a memory leak
+   but can be force-destructed. Unfortunately, Cython itself doesn't even
+   allow calling destructors for structs, so it has to be done externally.
+   This function should otherwise have no reason to exist.
+*/
+void dealloc_ModelOutputs(ModelOutputs &model_outputs)
+{
+    model_outputs.~ModelOutputs();
+}
