@@ -78,7 +78,9 @@ bool find_new_outliers(double *restrict numeric_data,
     bool col_is_num;
 
     bool found_outliers = false;
-    #if defined(_OPENMP) && ((_OPENMP < 200801) || defined(_WIN32) || defined(_WIN64))
+    if (nrows < (size_t)nthreads)
+        nthreads = (int) nrows;
+    #if defined(_OPENMP)
         std::vector<char> outliers_thread(nthreads, false);
     #endif
 
@@ -99,13 +101,8 @@ bool find_new_outliers(double *restrict numeric_data,
         col_is_num = col < model_outputs.ncols_numeric;
 
         /* Note: earlier versions of OpenMP (like v2 released in 2000 and still used by MSVC in 2019) don't support max reduction, hence this code */
-        #ifdef _OPENMP
-            #if (_OPENMP > 200801) && !defined(_WIN32) && !defined(_WIN64)
-                #pragma omp parallel for schedule(dynamic) num_threads(nthreads) shared(model_outputs, nrows, prediction_data) firstprivate(col_is_num, col) private(num_val_this, cat_val_this) reduction(+:found_outliers)
-            #else
-                #pragma omp parallel for schedule(dynamic) num_threads(nthreads) shared(model_outputs, outliers_thread, nrows, prediction_data) firstprivate(col_is_num, col) private(num_val_this, cat_val_this)
-            #endif
-        #endif
+        #pragma omp parallel for schedule(dynamic) num_threads(nthreads) shared(model_outputs, outliers_thread, nrows, prediction_data) \
+                    firstprivate(col_is_num, col) private(num_val_this, cat_val_this)
         for (size_t_for row = 0; row < nrows; row++) {
             
             /* first make a pre-check that the value could be flagged as outlier in some cluster */
@@ -132,12 +129,8 @@ bool find_new_outliers(double *restrict numeric_data,
             }
 
             #ifdef _OPENMP
-                #if _OPENMP > 200801 && !defined(_WIN32) && !defined(_WIN64)
-                    found_outliers += follow_tree(model_outputs, prediction_data, 0, 0, row, col, col_is_num, num_val_this, cat_val_this);
-                #else
-                    outliers_thread[omp_get_thread_num()] = follow_tree(model_outputs, prediction_data, 0, 0, row, col, col_is_num, num_val_this, cat_val_this)?
-                                                            true : outliers_thread[omp_get_thread_num()];
-                #endif
+                outliers_thread[omp_get_thread_num()] = follow_tree(model_outputs, prediction_data, 0, 0, row, col, col_is_num, num_val_this, cat_val_this)?
+                                                        true : outliers_thread[omp_get_thread_num()];
             #else 
                 found_outliers = std::max(found_outliers, follow_tree(model_outputs, prediction_data, 0, 0, row, col, col_is_num, num_val_this, cat_val_this));
             #endif
@@ -145,7 +138,7 @@ bool find_new_outliers(double *restrict numeric_data,
         }
     }
 
-    #if defined(_OPENMP) && ((_OPENMP < 200801) || defined(_WIN32) || defined(_WIN64))
+    #if defined(_OPENMP)
         for (size_t tid = 0; tid < outliers_thread.size(); tid++) {
             if (outliers_thread[tid] != 0) return true;
         }
